# CSS Flexbox

A CSS feature to position multiple items inside a container (parent) along **main axis** (along which items are laid out, horizontal by default) and **cross axis** (vertical by default).

Parent element has the following rule set:

```css
div {
  display: flex;
}
```

## Justify-content

```css
div {
  display: flex;
  justify-content: space-between;
}
```

Position items along main axis.

Possible values: flex-start, flex-end, center, space-between, space-around, space-evenly.

### Flex-start (default)

![Items are positioned to the start of main axis.](justify-content-flex-start.jpg)

### Flex-end

![Items are positioned to the end of main axis.](justify-content-flex-end.jpg)

### Center

![Items are positioned to the center of main axis.](justify-content-center.jpg)

### Space-between

![Items are distributed along main axis, with same amount of whitespace between them.](justify-content-space-between.jpg)

### Space-around

![Items are distributed along main axis, with whitespace around them. Whitespace between two elements is twice as much as at the start and end of main axis.](justify-content-space-around.jpg)

### Space-evenly

![Items are distributed along main axis, with the same amount of whitespace around them.](justify-content-space-evenly.jpg)

## Align-items

```css
div {
  display: flex;
  align-items: center;
}
```

Position items along cross axis.

Possible values: normal/stretch, flex-start, flex-end, center, baseline.

### Normal/stretch (default)

![Items are stretched to fit the length of cross axis.](align-items-stretch.jpg)

### Flex-start

![Items are positioned to the start of cross axis.](align-items-flex-start.jpg)

### Flex-end

![Items are positioned to the end of cross axis.](align-items-flex-end.jpg)

### Center

![Items are positioned to the center of cross axis.](align-items-center.jpg)

### Baseline

![Items are positioned so that their contents are aligned with each other. One of them is positioned to the start of cross axis.](align-items-baseline.jpg)

## Flex-direction

```css
div {
  display: flex;
  flex-direction: column;
}
```

Set direction of main axis.

Possible values: row, row-reverse, column, column-reverse.

### Row (default)

![Main axis is horizontal, left-to-right.](flex-direction-row.jpg)

### Row-reverse

![Main axis is horizontal, right-to-left.](flex-direction-row-reverse.jpg)

### Column

![Main axis is vertical, up-to-down.](flex-direction-column.jpg)

### Column-reverse

![Main axis is vertical, down-to-up.](flex-direction-column-reverse.jpg)

## Flex-wrap

```css
div {
  display: flex;
  flex-wrap: wrap;
}
```

Set whether items should be wrapped into a new line or not, if can't fit all of them into one.

Possible values: nowrap, wrap, wrap-reverse.

### Nowrap (default)

![Items are shrunk as much as possible, then they overflow the container.](flex-wrap-nowrap.jpg)

### Wrap

![Items aren't shrunk, they are wrapped into a new line if overflow.](flex-wrap-wrap.jpg)

### Wrap-reverse

![Same as wrap, except lines are in reversed order.](flex-wrap-wrap-reverse.jpg)

## Flex-grow

```css
div {
  display: flex;
}
div .flex-item {
  flex-grow: 2;
}
```

A property for flex item to set how much it can grow compared to other items.

It can have any (zero or positive) number as value. Default value is 0.

![First item with flex-grow 0 takes the width of its content, the second one has flex-grow 1, the third one with flex-grow 2 is twice as big as the second one, the fourth one with flex-grow 3 is three times as big as the second one.](flex-grow.jpg)(First item takes the width of its content, third is twice as big as second, fourth is three times as big.)
